@@ -1,9 +1,9 @@
 package Lemonldap::Handlers::MatrixPolicy;
 use strict;
 use warnings;
-our $VERSION = '2.00';
-our $VERSION_LEMONLDAP = "2.0";
-our $VERSION_INTERNAL  = "2.0";
+our $VERSION = '3.1.0';
+our $VERSION_LEMONLDAP = "3.1";
+our $VERSION_INTERNAL  = "3.1";
 
 sub get                
 {
@@ -41,15 +41,14 @@ sub get
      }
    }  
    
-   $self->{response} = 503  if  lc($config->{ALLOW})  eq 'disabled';
-
    unless (defined $complement)  {
    $complement = '_DENY_'; 
    $self->{response} = 403; #403 = FORBIDDEN  200 = OK 
-   $complement =  '_ALLOW_' && $self->{response} = '_ALLOW_'  if  lc($config->{ALLOW})  eq 'all';
+   $complement =  '_ALLOW_' && $self->{response} = '200'  if  lc($config->{ALLOW})  eq 'all';
    undef $complement if ($self->{response} == '403' or $self->{response} == '503' );
    }
  
+   $self->{response} = 503  if  lc($config->{ALLOW})  eq 'disabled';
    undef $complement if ($self->{response} == '403' or $self->{response} == '503' );
    $self->{profil} = $complement ;
    bless $self,$class;
